OC.L10N.register(
    "bruteforcesettings",
    {
    "Brute-force settings" : "Jõuründe piiramise meetmete seadistused",
    "Whitelist IPs" : "Lubatud IP-aadressid",
    "Comment cannot exceed {max} characters." : "Kommentaar ei või olla pikem, kui {max} tähemärki",
    "Your remote address was identified as \"{remoteAddress}\" and is throttled at the moment by {delay}ms." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel jõuründe piiramise meetmena kasutusel {delay}-millisekundiline viivitus.",
    "Your remote address was identified as \"{remoteAddress}\" and is bypassing brute-force protection." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel ei kehti jõuründe piiramise meetmed.",
    "Your remote address was identified as \"{remoteAddress}\" and is not actively throttled at the moment." : "Sinu arvuti või seadme aadress on tuvastatud kui „{remoteAddress}“ ja selle puhul on hetkel ei kasutada jõuründe piiramise meetmena päringute viivitamist.",
    "Add new IP address" : "Lisa uus IP-aadress",
    "IP address" : "IP-address",
    "Mask" : "Aadressi mask",
    "Comment" : "Kommentaar",
    "Add" : "Lisa",
    "Edit comment for {subnet}" : "Muuda „{subnet}“ kommentaari",
    "Save" : "Salvesta",
    "Delete entry for {subnet}" : "Kustuta „{subnet}“ kirje"
},
"nplurals=2; plural=(n != 1);");
